#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 placeholders
version:              0.1
visibility:           public
id:                   placeholders-0.1-74z1Gh2SURj3Va5KDF8HCG
key:                  placeholders-0.1-74z1Gh2SURj3Va5KDF8HCG
license:              BSD-3-Clause
copyright:            (c) 2011 Andreas Hammar
maintainer:           Andreas Hammar <ahammar@gmail.com>
author:               Andreas Hammar
homepage:             http://github.com/ahammar/placeholders
synopsis:             Placeholders for use while developing Haskell code
description:
    While working on some Haskell code, it is often useful to
    work incrementally by inserting @undefined@ as a
    placeholder for missing code.

    This library provides placeholders that produce better
    messages when evaluated at run-time and also generate
    compile-time warnings so that they do not get forgotten
    so easily.
    For details, see <http://github.com/ahammar/placeholders>

category:             Development
abi:                  593cd96bf20cb056a97fa9147e7de49e
exposed:              True
exposed-modules:      Development.Placeholders
import-dirs:          /usr/lib/ghc-9.6.6/site-local/placeholders-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/placeholders-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/placeholders-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-placeholders
hs-libraries:         HSplaceholders-0.1-74z1Gh2SURj3Va5KDF8HCG
depends:              base-4.18.2.1 template-haskell-2.20.0.0
haddock-interfaces:
    /usr/share/doc/haskell-placeholders/html/placeholders.haddock

haddock-html:         /usr/share/doc/haskell-placeholders/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

